==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/fa.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "ارسال ایمیل برای کاربران روبرو با شکست مواجه شد : %s",
    "Preparing update" : "آماده‌سازی به روز‌ رسانی",
    "Turned on maintenance mode" : "حالت \" در دست تعمیر \" فعال شد .",
    "Turned off maintenance mode" : "حالت \" در دست تعمیر \" غیرفعال شد .",
    "Maintenance mode is kept active" : "حالت تعمیرات فعال نگه‌داشته شده است",
    "Updated database" : "بروز رسانی پایگاه داده انجام شد .",
    "Updated \"%s\" to %s" : "\"%s\" به %s بروزرسانی شد",
    "Repair warning: " : "اخطار تعمیر:",
    "Repair error: " : "خطای تعمیر:",
    "Already up to date" : "در حال حاضر بروز است",
    "File is too big" : "فایل خیلی بزرگ است",
    "Invalid file provided" : "فایل داده‌شده نا معتبر است",
    "No image or file provided" : "هیچ فایل یا تصویری وارد نشده است",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "Invalid image" : "عکس نامعتبر",
    "No temporary profile picture available, try again" : "تصویر پروفایل موقت در حال حاضر در دسترس نیست ، دوباره تلاش کنید ",
    "Sunday" : "یکشنبه",
    "Monday" : "دوشنبه",
    "Tuesday" : "سه شنبه",
    "Wednesday" : "چهارشنبه",
    "Thursday" : "پنجشنبه",
    "Friday" : "جمعه",
    "Saturday" : "شنبه",
    "Sun." : "یکشنبه",
    "Mon." : "دوشنبه",
    "Tue." : "سه شنبه",
    "Wed." : "چهارشنبه",
    "Thu." : "پنج شنبه",
    "Fri." : "جمعه",
    "Sat." : "شنبه",
    "Su" : "یک‌شنبه",
    "Mo" : "دوشنبه",
    "Tu" : "سه‌شنبه",
    "We" : "چهار‌شنبه",
    "Th" : "پنج‌شنبه",
    "Fr" : "جمعه",
    "Sa" : "شنبه",
    "January" : "ژانویه",
    "February" : "فبریه",
    "March" : "مارس",
    "April" : "آوریل",
    "May" : "می",
    "June" : "ژوئن",
    "July" : "جولای",
    "August" : "آگوست",
    "September" : "سپتامبر",
    "October" : "اکتبر",
    "November" : "نوامبر",
    "December" : "دسامبر",
    "Jan." : "ژانویه",
    "Feb." : "فوریه",
    "Mar." : "مارچ",
    "Apr." : "آوریل",
    "May." : "می",
    "Jun." : "ژوئن",
    "Jul." : "جولای",
    "Aug." : "آگوست",
    "Sep." : "سپتامبر",
    "Oct." : "اکتبر",
    "Nov." : "نوامبر",
    "Dec." : "دسامبر",
    "Settings" : "تنظیمات",
    "Saving..." : "در حال ذخیره سازی...",
    "seconds ago" : "ثانیه‌ها پیش",
    "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "لینک تنظیم مجدد رمز عبور به ایمیل شما ارسال شده است.<br>اگر آن رادر یک زمان مشخصی دریافت نکرده اید، لطفا هرزنامه/ پوشه های ناخواسته را بررسی کنید.<br>در صورت نبودن از مدیر خود بپرسید.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "فایل های شما رمزگذاری شده اند. اگر شما کلید بازیابی را فعال نکرده اید، پس از راه اندازی مجدد رمزعبور هیچ راهی برای بازگشت اطلاعاتتان وجود نخواهد داشت.در صورت عدم اطمینان به انجام کار، لطفا ابتدا با مدیر خود تماس بگیرید. آیا واقعا میخواهید ادامه دهید ؟",
    "I know what I'm doing" : "اطلاع از انجام این کار دارم",
    "Password can not be changed. Please contact your administrator." : "رمز عبور نمی تواند تغییر بکند . لطفا با مدیر سیستم تماس بگیرید .",
    "No" : "نه",
    "Yes" : "بله",
    "Choose" : "انتخاب کردن",
    "Error loading file picker template: {error}" : "خطا در بارگذاری قالب انتخاب فایل : {error}",
    "Ok" : "قبول",
    "Error loading message template: {error}" : "خطا در بارگذاری قالب پیام : {error}",
    "read-only" : "فقط-خواندنی",
    "One file conflict" : "یک فایل متضاد",
    "New Files" : "فایل های جدید",
    "Already existing files" : "فایل های موجود در حال حاضر ",
    "Which files do you want to keep?" : "کدام فایل ها را می خواهید نگه دارید ؟",
    "Cancel" : "منصرف شدن",
    "Continue" : "ادامه",
    "(all selected)" : "(همه انتخاب شده اند)",
    "({count} selected)" : "({count} انتخاب شده)",
    "Error loading file exists template" : "خطا در بارگزاری فایل قالب",
    "Very weak password" : "رمز عبور بسیار ضعیف",
    "Weak password" : "رمز عبور ضعیف",
    "So-so password" : "رمز عبور متوسط",
    "Good password" : "رمز عبور خوب",
    "Strong password" : "رمز عبور قوی",
    "Shared" : "اشتراک گذاشته شده",
    "Shared with {recipients}" : "به اشتراک گذاشته شده با {recipients}",
    "Error" : "خطا",
    "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
    "Error while unsharing" : "خطا درحال لغو اشتراک",
    "Error while changing permissions" : "خطا در حال تغییر مجوز",
    "Error setting expiration date" : "خطا در تنظیم تاریخ انقضا",
    "The public link will expire no later than {days} days after it is created" : "لینک عمومی پس از {days} روز پس از ایجاد منقضی خواهد شد",
    "Set expiration date" : "تنظیم تاریخ انقضا",
    "Expiration" : "تاریخ انقضا",
    "Expiration date" : "تاریخ انقضا",
    "Sending ..." : "درحال ارسال ...",
    "Email sent" : "ایمیل ارسال شد",
    "Resharing is not allowed" : "اشتراک گذاری مجدد مجاز نمی باشد",
    "Share link" : "اشتراک گذاشتن لینک",
    "Link" : "لینک",
    "Password protect" : "نگهداری کردن رمز عبور",
    "Password" : "گذرواژه",
    "Choose a password for the public link" : "انتخاب رمز برای لینک عمومی",
    "Allow editing" : "اجازه‌ی ویرایش",
    "Email link to person" : "پیوند ایمیل برای شخص.",
    "Send" : "ارسال",
    "Shared with you and the group {group} by {owner}" : "به اشتراک گذاشته شده با شما و گروه {گروه} توسط {دارنده}",
    "Shared with you by {owner}" : "به اشتراک گذاشته شده با شما توسط { دارنده}",
    "Shared in {item} with {user}" : "به اشتراک گذاشته شده در {بخش} با {کاربر}",
    "group" : "گروه",
    "remote" : "از راه دور",
    "notify by email" : "دریافت هشدار از طریق ایمیل",
    "Unshare" : "لغو اشتراک",
    "can share" : "قابل به اشتراک گذاری",
    "can edit" : "می توان ویرایش کرد",
    "create" : "ایجاد",
    "change" : "تغییر",
    "delete" : "پاک کردن",
    "access control" : "کنترل دسترسی",
    "An error occured. Please try again" : "یک خطا رخ داده است، لطفا مجددا تلاش کنید",
    "Share" : "اشتراک‌گذاری",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "اشتراک‌گذاری با دیگر افراد بر روی ownClouds بصورت username@example.com/owncloud",
    "Share with users or groups …" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "Share with users, groups or remote users …" : "اشتراک گذاری با کاربران، گروه‌ها یا کاربران راه دور...",
    "Warning" : "اخطار",
    "Error while sending notification" : "خطا در حین ارسال نوتیفیکیشن",
    "The object type is not specified." : "نوع شی تعیین نشده است.",
    "Enter new" : "مورد جدید را وارد کنید",
    "Delete" : "حذف",
    "Add" : "افزودن",
    "Edit tags" : "ویرایش تگ ها",
    "unknown text" : "متن نامعلوم",
    "Hello world!" : "سلام دنیا!",
    "sunny" : "آفتابی",
    "Hello {name}, the weather is {weather}" : "سلام {name}, هوا  {weather} است",
    "Hello {name}" : "سلام {name}",
    "_download %n file_::_download %n files_" : ["دانلود %n فایل"],
    "The update was unsuccessful. " : "بروزرسانی ناموفق بود.",
    "The update was successful. There were warnings." : "بروزرسانی با موفقیت انجام شد، اخطارهایی وجود دارد.",
    "The update was successful. Redirecting you to ownCloud now." : "به روزرسانی موفقیت آمیز بود. در حال انتقال شما به OwnCloud.",
    "%s password reset" : "%s رمزعبور تغییر کرد",
    "Use the following link to reset your password: {link}" : "از لینک زیر جهت دوباره سازی پسورد استفاده کنید :\n{link}",
    "New password" : "گذرواژه جدید",
    "New Password" : "رمزعبور جدید",
    "Reset password" : "تنظیم مجدد رمز عبور",
    "Personal" : "شخصی",
    "Users" : "کاربران",
    "Apps" : "  برنامه ها",
    "Admin" : "مدیر",
    "Help" : "راه‌نما",
    "Error loading tags" : "خطا در هنگام بارگزاری تگ ها",
    "Tag already exists" : "تگ از قبل وجود دارد",
    "Error deleting tag(s)" : "خطا در هنگام حذف تگ (ها)",
    "Error tagging" : "خطا در هنگام تگ گذاری",
    "Error untagging" : "خطا در هنگام حذف تگ",
    "Error favoriting" : "خطا هنگام افزودن به موارد محبوب",
    "Error unfavoriting" : "خطا هنگام حذف از موارد محبوب",
    "Access forbidden" : "اجازه دسترسی به مناطق ممنوعه را ندارید",
    "File not found" : "فایل یافت نشد",
    "The share will expire on %s." : "اشتراک‌گذاری در %s منقضی خواهد شد.",
    "Cheers!" : "سلامتی!",
    "Internal Server Error" : "خطای داخلی سرور",
    "Technical details" : "جزئیات فنی",
    "Remote Address: %s" : "آدرس راه‌دور: %s",
    "Request ID: %s" : "ID درخواست: %s",
    "Type: %s" : "نوع: %s",
    "Code: %s" : "کد: %s",
    "Message: %s" : "پیام: %s",
    "File: %s" : "فایل : %s",
    "Line: %s" : "خط: %s",
    "Security warning" : "اخطار امنیتی",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
    "Create an <strong>admin account</strong>" : "لطفا یک <strong> شناسه برای مدیر</strong> بسازید",
    "Username" : "نام کاربری",
    "Storage & database" : "انبارش و پایگاه داده",
    "Data folder" : "پوشه اطلاعاتی",
    "Configure the database" : "پایگاه داده برنامه ریزی شدند",
    "Only %s is available." : "تنها %s موجود است.",
    "Database user" : "شناسه پایگاه داده",
    "Database password" : "پسورد پایگاه داده",
    "Database name" : "نام پایگاه داده",
    "Database tablespace" : "جدول پایگاه داده",
    "Database host" : "هاست پایگاه داده",
    "Performance warning" : "اخطار کارایی",
    "Finish setup" : "اتمام نصب",
    "Finishing …" : "در حال اتمام ...",
    "Need help?" : "کمک لازم دارید ؟",
    "See the documentation" : "مشاهده‌ی مستندات",
    "Log out" : "خروج",
    "Search" : "جست‌و‌جو",
    "Please contact your administrator." : "لطفا با مدیر وب‌سایت تماس بگیرید.",
    "An internal error occured." : "یک خطای داخلی رخ داده‌است.",
    "Please try again or contact your administrator." : "لطفا مجددا تلاش کنید یا با مدیر سیستم تماس بگیرید.",
    "Log in" : "ورود",
    "remember" : "بیاد آوری",
    "Alternative Logins" : "ورود متناوب",
    "Thank you for your patience." : "از صبر شما متشکریم",
    "Add \"%s\" as trusted domain" : "افزودن \"%s\" به عنوان دامنه مورد اعتماد",
    "These apps will be updated:" : "این برنامه‌ها بروزرسانی شده‌اند:",
    "The theme %s has been disabled." : "قالب %s غیر فعال شد.",
    "Start update" : "اغاز به روز رسانی"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/fa.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "ارسال ایمیل برای کاربران روبرو با شکست مواجه شد : %s",
    "Preparing update" : "آماده‌سازی به روز‌ رسانی",
    "Turned on maintenance mode" : "حالت \" در دست تعمیر \" فعال شد .",
    "Turned off maintenance mode" : "حالت \" در دست تعمیر \" غیرفعال شد .",
    "Maintenance mode is kept active" : "حالت تعمیرات فعال نگه‌داشته شده است",
    "Updated database" : "بروز رسانی پایگاه داده انجام شد .",
    "Updated \"%s\" to %s" : "\"%s\" به %s بروزرسانی شد",
    "Repair warning: " : "اخطار تعمیر:",
    "Repair error: " : "خطای تعمیر:",
    "Already up to date" : "در حال حاضر بروز است",
    "File is too big" : "فایل خیلی بزرگ است",
    "Invalid file provided" : "فایل داده‌شده نا معتبر است",
    "No image or file provided" : "هیچ فایل یا تصویری وارد نشده است",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "Invalid image" : "عکس نامعتبر",
    "An error occurred. Please contact your admin." : "یک خطا رخ داده است. لطفا با مدیر سیستم تماس بگیرید.",
    "No temporary profile picture available, try again" : "تصویر پروفایل موقت در حال حاضر در دسترس نیست ، دوباره تلاش کنید ",
    "Crop is not square" : "بخش بریده شده مربع نیست",
    "%s password reset" : "%s رمزعبور تغییر کرد",
    "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
    "Sunday" : "یکشنبه",
    "Monday" : "دوشنبه",
    "Tuesday" : "سه شنبه",
    "Wednesday" : "چهارشنبه",
    "Thursday" : "پنجشنبه",
    "Friday" : "جمعه",
    "Saturday" : "شنبه",
    "Sun." : "یکشنبه",
    "Mon." : "دوشنبه",
    "Tue." : "سه شنبه",
    "Wed." : "چهارشنبه",
    "Thu." : "پنج شنبه",
    "Fri." : "جمعه",
    "Sat." : "شنبه",
    "Su" : "یک‌شنبه",
    "Mo" : "دوشنبه",
    "Tu" : "سه‌شنبه",
    "We" : "چهار‌شنبه",
    "Th" : "پنج‌شنبه",
    "Fr" : "جمعه",
    "Sa" : "شنبه",
    "January" : "ژانویه",
    "February" : "فبریه",
    "March" : "مارس",
    "April" : "آوریل",
    "May" : "می",
    "June" : "ژوئن",
    "July" : "جولای",
    "August" : "آگوست",
    "September" : "سپتامبر",
    "October" : "اکتبر",
    "November" : "نوامبر",
    "December" : "دسامبر",
    "Jan." : "ژانویه",
    "Feb." : "فوریه",
    "Mar." : "مارچ",
    "Apr." : "آوریل",
    "May." : "می",
    "Jun." : "ژوئن",
    "Jul." : "جولای",
    "Aug." : "آگوست",
    "Sep." : "سپتامبر",
    "Oct." : "اکتبر",
    "Nov." : "نوامبر",
    "Dec." : "دسامبر",
    "Settings" : "تنظیمات",
    "Saving..." : "در حال ذخیره سازی...",
    "Dismiss" : "پنهان کن",
    "seconds ago" : "ثانیه‌ها پیش",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "لینک تنظیم مجدد رمز عبور به ایمیل شما ارسال شده است.<br>اگر آن رادر یک زمان مشخصی دریافت نکرده اید، لطفا هرزنامه/ پوشه های ناخواسته را بررسی کنید.<br>در صورت نبودن از مدیر خود بپرسید.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "فایل های شما رمزگذاری شده اند. اگر شما کلید بازیابی را فعال نکرده اید، پس از راه اندازی مجدد رمزعبور هیچ راهی برای بازگشت اطلاعاتتان وجود نخواهد داشت.در صورت عدم اطمینان به انجام کار، لطفا ابتدا با مدیر خود تماس بگیرید. آیا واقعا میخواهید ادامه دهید ؟",
    "I know what I'm doing" : "اطلاع از انجام این کار دارم",
    "Password can not be changed. Please contact your administrator." : "رمز عبور نمی تواند تغییر بکند . لطفا با مدیر سیستم تماس بگیرید .",
    "No" : "نه",
    "Yes" : "بله",
    "Choose" : "انتخاب کردن",
    "Error loading file picker template: {error}" : "خطا در بارگذاری قالب انتخاب فایل : {error}",
    "Ok" : "قبول",
    "Error loading message template: {error}" : "خطا در بارگذاری قالب پیام : {error}",
    "read-only" : "فقط-خواندنی",
    "One file conflict" : "یک فایل متضاد",
    "New Files" : "فایل های جدید",
    "Already existing files" : "فایل های موجود در حال حاضر ",
    "Which files do you want to keep?" : "کدام فایل ها را می خواهید نگه دارید ؟",
    "Cancel" : "منصرف شدن",
    "Continue" : "ادامه",
    "(all selected)" : "(همه انتخاب شده اند)",
    "({count} selected)" : "({count} انتخاب شده)",
    "Error loading file exists template" : "خطا در بارگزاری فایل قالب",
    "Very weak password" : "رمز عبور بسیار ضعیف",
    "Weak password" : "رمز عبور ضعیف",
    "So-so password" : "رمز عبور متوسط",
    "Good password" : "رمز عبور خوب",
    "Strong password" : "رمز عبور قوی",
    "Error occurred while checking server setup" : "خطا در هنگام چک کردن راه‌اندازی سرور رخ داده است",
    "Shared" : "اشتراک گذاشته شده",
    "Shared with {recipients}" : "به اشتراک گذاشته شده با {recipients}",
    "Error" : "خطا",
    "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
    "Error while unsharing" : "خطا درحال لغو اشتراک",
    "Error setting expiration date" : "خطا در تنظیم تاریخ انقضا",
    "The public link will expire no later than {days} days after it is created" : "لینک عمومی پس از {days} روز پس از ایجاد منقضی خواهد شد",
    "Set expiration date" : "تنظیم تاریخ انقضا",
    "Expiration" : "تاریخ انقضا",
    "Expiration date" : "تاریخ انقضا",
    "Choose a password for the public link" : "انتخاب رمز برای لینک عمومی",
    "Sending ..." : "درحال ارسال ...",
    "Email sent" : "ایمیل ارسال شد",
    "Resharing is not allowed" : "اشتراک گذاری مجدد مجاز نمی باشد",
    "Share link" : "اشتراک گذاشتن لینک",
    "Link" : "لینک",
    "Password protect" : "نگهداری کردن رمز عبور",
    "Password" : "گذرواژه",
    "Allow editing" : "اجازه‌ی ویرایش",
    "Email link to person" : "پیوند ایمیل برای شخص.",
    "Send" : "ارسال",
    "Shared with you and the group {group} by {owner}" : "به اشتراک گذاشته شده با شما و گروه {گروه} توسط {دارنده}",
    "Shared with you by {owner}" : "به اشتراک گذاشته شده با شما توسط { دارنده}",
    "group" : "گروه",
    "remote" : "از راه دور",
    "notify by email" : "دریافت هشدار از طریق ایمیل",
    "Unshare" : "لغو اشتراک",
    "can share" : "قابل به اشتراک گذاری",
    "can edit" : "می توان ویرایش کرد",
    "create" : "ایجاد",
    "change" : "تغییر",
    "delete" : "پاک کردن",
    "access control" : "کنترل دسترسی",
    "An error occured. Please try again" : "یک خطا رخ داده است، لطفا مجددا تلاش کنید",
    "Share" : "اشتراک‌گذاری",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "اشتراک‌گذاری با دیگر افراد بر روی ownClouds بصورت username@example.com/owncloud",
    "Share with users or groups …" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "Share with users, groups or remote users …" : "اشتراک گذاری با کاربران، گروه‌ها یا کاربران راه دور...",
    "Warning" : "اخطار",
    "Error while sending notification" : "خطا در حین ارسال نوتیفیکیشن",
    "Delete" : "حذف",
    "Rename" : "تغییرنام",
    "The object type is not specified." : "نوع شی تعیین نشده است.",
    "Enter new" : "مورد جدید را وارد کنید",
    "Add" : "افزودن",
    "Edit tags" : "ویرایش تگ ها",
    "No tags selected for deletion." : "هیچ تگی برای حذف انتخاب نشده است.",
    "unknown text" : "متن نامعلوم",
    "Hello world!" : "سلام دنیا!",
    "sunny" : "آفتابی",
    "Hello {name}, the weather is {weather}" : "سلام {name}, هوا  {weather} است",
    "Hello {name}" : "سلام {name}",
    "_download %n file_::_download %n files_" : ["دانلود %n فایل"],
    "Updating {productName} to version {version}, this may take a while." : "بروزرسانی {productName}  به نسخه‎ی  {version}، این عملیات ممکن است زمان‎بر باشد.",
    "An error occurred." : "یک خطا رخ‌داده است.",
    "The update was unsuccessful. " : "بروزرسانی ناموفق بود.",
    "The update was successful. There were warnings." : "بروزرسانی با موفقیت انجام شد، اخطارهایی وجود دارد.",
    "The update was successful. Redirecting you to ownCloud now." : "به روزرسانی موفقیت آمیز بود. در حال انتقال شما به OwnCloud.",
    "Searching other places" : "جستجو در مکان‌های دیگر",
    "Personal" : "شخصی",
    "Users" : "کاربران",
    "Apps" : "  برنامه ها",
    "Admin" : "مدیر",
    "Help" : "راه‌نما",
    "Error loading tags" : "خطا در هنگام بارگزاری تگ ها",
    "Tag already exists" : "تگ از قبل وجود دارد",
    "Error deleting tag(s)" : "خطا در هنگام حذف تگ (ها)",
    "Error tagging" : "خطا در هنگام تگ گذاری",
    "Error untagging" : "خطا در هنگام حذف تگ",
    "Error favoriting" : "خطا هنگام افزودن به موارد محبوب",
    "Error unfavoriting" : "خطا هنگام حذف از موارد محبوب",
    "Access forbidden" : "اجازه دسترسی به مناطق ممنوعه را ندارید",
    "File not found" : "فایل یافت نشد",
    "The specified document has not been found on the server." : "مستند مورد نظر در سرور یافت نشد.",
    "You can click here to return to %s." : "شما می‎توانید برای بازگشت به  %s اینجا کلیک کنید.",
    "The share will expire on %s." : "اشتراک‌گذاری در %s منقضی خواهد شد.",
    "Cheers!" : "سلامتی!",
    "Internal Server Error" : "خطای داخلی سرور",
    "More details can be found in the server log." : "جزئیات بیشتر در لاگ سرور قابل مشاهده خواهد بود.",
    "Technical details" : "جزئیات فنی",
    "Remote Address: %s" : "آدرس راه‌دور: %s",
    "Request ID: %s" : "ID درخواست: %s",
    "Type: %s" : "نوع: %s",
    "Code: %s" : "کد: %s",
    "Message: %s" : "پیام: %s",
    "File: %s" : "فایل : %s",
    "Line: %s" : "خط: %s",
    "Security warning" : "اخطار امنیتی",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
    "Create an <strong>admin account</strong>" : "لطفا یک <strong> شناسه برای مدیر</strong> بسازید",
    "Username" : "نام کاربری",
    "Storage & database" : "انبارش و پایگاه داده",
    "Data folder" : "پوشه اطلاعاتی",
    "Configure the database" : "پایگاه داده برنامه ریزی شدند",
    "Only %s is available." : "تنها %s موجود است.",
    "Install and activate additional PHP modules to choose other database types." : "جهت انتخاب انواع دیگر پایگاه‌داده‌،ماژول‌های اضافی PHP را نصب و فعال‌سازی کنید.",
    "For more details check out the documentation." : "برای جزئیات بیشتر به مستندات مراجعه کنید.",
    "Database user" : "شناسه پایگاه داده",
    "Database password" : "پسورد پایگاه داده",
    "Database name" : "نام پایگاه داده",
    "Database tablespace" : "جدول پایگاه داده",
    "Database host" : "هاست پایگاه داده",
    "Performance warning" : "اخطار کارایی",
    "SQLite will be used as database." : "SQLite به عنوان پایگاه‎داده استفاده خواهد شد.",
    "Finish setup" : "اتمام نصب",
    "Finishing …" : "در حال اتمام ...",
    "Need help?" : "کمک لازم دارید ؟",
    "See the documentation" : "مشاهده‌ی مستندات",
    "Log out" : "خروج",
    "Search" : "جست‌و‌جو",
    "Please contact your administrator." : "لطفا با مدیر وب‌سایت تماس بگیرید.",
    "An internal error occured." : "یک خطای داخلی رخ داده‌است.",
    "Please try again or contact your administrator." : "لطفا مجددا تلاش کنید یا با مدیر سیستم تماس بگیرید.",
    "Log in" : "ورود",
    "Alternative Logins" : "ورود متناوب",
    "Use the following link to reset your password: {link}" : "از لینک زیر جهت دوباره سازی پسورد استفاده کنید :\n{link}",
    "New password" : "گذرواژه جدید",
    "New Password" : "رمزعبور جدید",
    "Reset password" : "تنظیم مجدد رمز عبور",
    "Thank you for your patience." : "از صبر شما متشکریم",
    "Add \"%s\" as trusted domain" : "افزودن \"%s\" به عنوان دامنه مورد اعتماد",
    "App update required" : "نیاز به بروزرسانی برنامه وجود دارد",
    "%s will be updated to version %s" : "%s به نسخه‌ی %s بروزرسانی خواهد شد",
    "These apps will be updated:" : "این برنامه‌ها بروزرسانی شده‌اند:",
    "The theme %s has been disabled." : "قالب %s غیر فعال شد.",
    "Start update" : "اغاز به روز رسانی",
    "Error loading file picker template: {error}" : "خطا در بارگذاری قالب انتخاب فایل : {error}",
    "Password can not be changed. Please contact your administrator." : "رمز عبور نمی تواند تغییر بکند . لطفا با مدیر سیستم تماس بگیرید ."
},
"nplurals=1; plural=0;");
